export type DisplayMode = 'color' | 'text' | 'shape';
export interface Range {
    min: number | null;
    max: number | null;
}
export interface ShapeRadiusRange {
    min: number;
    max: number;
}
export interface OpacityRange {
    min: number;
    max: number;
}
export interface State {
    selectedAttributeIds: string[];
    valueRanges: Record<string, Range>;
    colors: Record<string, string>;
    opacities: Record<string, number>;
    displayModes: Record<string, DisplayMode>;
    textFormats: Record<string, string>;
    shapeRadiusRanges: Record<string, ShapeRadiusRange>;
    textSizes: Record<string, number>;
    opacityRanges: Record<string, OpacityRange>;
    nextColorIndex: number;
    hideDefaultRoomstamps: boolean;
}
export declare const defaults: {
    readonly textSize: 32;
    readonly shapeRadius: {
        readonly min: 0.2;
        readonly max: 1;
    };
    readonly opacity: {
        readonly boolean: 0.4;
        readonly default: 1;
        readonly numeric: {
            readonly min: 0.2;
            readonly max: 1;
        };
    };
};
export declare const state: {
    selectedAttributeIds: string[];
    valueRanges: Record<string, Range>;
    colors: Record<string, string>;
    opacities: Record<string, number>;
    displayModes: Record<string, DisplayMode>;
    textFormats: Record<string, string>;
    shapeRadiusRanges: Record<string, ShapeRadiusRange>;
    textSizes: Record<string, number>;
    opacityRanges: Record<string, OpacityRange>;
    nextColorIndex: number;
    hideDefaultRoomstamps: boolean;
};
export declare function resetState(): void;
export declare function useCustomAttribute(attrId: string): {
    definition: any;
    displayMode: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<DisplayMode, DisplayMode>;
    isNumeric: import('../vue/dist/vue.esm-browser.prod.js').ComputedRef<boolean>;
    textSize: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    textFormat: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<string, string>;
    opacity: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    color: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<string, string>;
    nodes: import('../vue/dist/vue.esm-browser.prod.js').ComputedRef<any>;
    numericValueRange: import('../vue/dist/vue.esm-browser.prod.js').ComputedRef<{
        minValue: number;
        maxValue: number;
    }>;
    valueRangeMin: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    valueRangeMax: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    opacityRangeMin: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    opacityRangeMax: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    radiusRangeMin: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
    radiusRangeMax: import('../vue/dist/vue.esm-browser.prod.js').WritableComputedRef<number, number>;
};
